@@ -232,12 +232,15 @@ def deepcopy(file_list, folder, replace = None):
 def stats(file_list, title = ""):
     file_list = FileList.check(file_list)
 
-    size = __exec("du %s | cut  -f1 |(tr '\n' '+'; echo 0) | bc" % ' '.join(file_list))
+    size = __exec("du -k  %s | cut  -f1 |(tr '\n' '+'; echo 0) | bc" % ' '.join(file_list))
+    
 
     try:
         size = int(size)
     except Exception:
         return 0
+    
+    size = size * 1024
 
     lines = __exec("wc -l %s | tail -1" % ' '.join(file_list))
     lines =  re.findall(r'\d+(?:\.\d+)?', lines)
